## cdist-type__group(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__group - Manage groups

## 2. DESCRIPTION

This cdist type allows you to create or modify groups on the target.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

gid
  see groupmod(8)
password
  see above

## 5. EXAMPLES

    # Create a group 'foobar' with operating system default settings
    __group foobar

    # Same but with a specific gid
    __group foobar --gid 1234

    # Same but with a gid and password
    __group foobar --gid 1234 --password 'crypted-password-string'

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2011 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).